"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.apiController = void 0;
const DecoratorRegistry_1 = require("../reflection/DecoratorRegistry");
/**
 * Decorator that can be placed on a class to mark it is an API controller.
 *
 * @param path A root URL path that all endpoints in this controller share; optional.
 *             This URL can contain path parameters, prefixed with a colon (':') character.
 */
function apiController(path) {
    return (constructor) => {
        let controller = DecoratorRegistry_1.DecoratorRegistry.getOrCreateController(constructor);
        DecoratorRegistry_1.DecoratorRegistry.getLogger().debug("@apiController('%s') decorator executed for controller: %s", path, controller.name);
        controller.path = path;
    };
}
exports.apiController = apiController;
//# sourceMappingURL=apiController.js.map