"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.apiRequest = void 0;
const util_1 = require("util");
const DecoratorRegistry_1 = require("../../reflection/DecoratorRegistry");
/**
 * Decorator that can be placed on an endpoint to describe the request
 * in any generated OpenAPI specification.
 *
 * @param apiBodyInfo Request body info.
 */
function apiRequest(apiBodyInfo) {
    return (classDefinition, methodName) => {
        let controller = DecoratorRegistry_1.DecoratorRegistry.getOrCreateController(classDefinition.constructor);
        let endpoint = DecoratorRegistry_1.DecoratorRegistry.getOrCreateEndpoint(controller, methodName);
        let operationInfo = endpoint.getOrCreateApiOperationInfo();
        let requestInfo = operationInfo.getOrCreateRequest();
        if (DecoratorRegistry_1.DecoratorRegistry.getLogger().debugEnabled()) {
            DecoratorRegistry_1.DecoratorRegistry.getLogger().debug("@apiRequest(%s) decorator executed for endpoint: %s", util_1.inspect(apiBodyInfo), endpoint.name);
        }
        requestInfo.mergeInfo(apiBodyInfo);
    };
}
exports.apiRequest = apiRequest;
//# sourceMappingURL=apiRequest.js.map