/**
 * Decorator for an endpoint method that defines roles that are allowed to use it.
 *
 * Overrides the controller roles set by the `controllerRolesAllowed` decorator, if any.
 *
 * Role based authorization is managed by an `IAuthorizer` implementation registered
 * with the current app.
 *
 * @param roleNames Names of roles that are permitted to use the endpoint.
 */
export declare function rolesAllowed(...roleNames: string[]): (classDefinition: Object | Function, methodName: string) => void;
/**
 * Decorator for a controller class that defines roles that are allowed to user all
 * endpoints within it.
 *
 * Role based authorization is managed by a `IAuthorizer` implementation registered
 * with the current app.
 *
 * @param roleNames Names of roles that are permitted to use the endpoints in this controller.
 */
export declare function controllerRolesAllowed(...roleNames: string[]): (classDefinition: Function) => void;
